require 'net/http'
require 'openssl'

module EmapicConsul
  class Api

    def self.build_generic_request(path)
      EmapicConsul::Request.new(
        host: api_host,
        path: path,
        port: api_port,
        api_key: api_key,
        api_secret: api_secret
      )
    end

    # create_location_group(proposal_instance)
    def self.create_location_group(group)
      print_debug_start("to notify proposal creation")

      request = build_generic_request("/api/locationgroup/#{emapic_login}")
      request.params = { id: "proposal_#{group.id}", title: group.title }
      response = request.send

      puts "Response body: #{response.body}"
      print_debug_end(response.code)
    end

    # vote_location_group(proposal_instance, latitude, longitude)
    def self.vote_location_group(group, latitude, longitude)
      print_debug_start("to notify vote creation with lat/lng")

      request = build_generic_request("/api/locationgroup/#{emapic_login}/proposal_#{group.id}")
      request.params = { user_id: nil, lat: latitude, lng: longitude }
      response = request.send

      puts "Response body: #{response.body}"
      print_debug_end(response.code)
    end

    # def self.get_random_address
    #   print_debug_start("to get the address")
    #
    #   uri = EmapicConsul::Request.build_uri(api_host, '/api/randomMadrid', api_port)
    #   # The build_http_object is not meant to be called from this class. But when
    #   # the get_random_address method disappears this call will be deleted
    #   http = EmapicConsul::Request.build_http_object(uri)
    #   request = Net::HTTP::Get.new(uri)
    #
    #   response = http.request(request)
    #
    #   puts "Address: #{JSON.parse(response.body)['display_name']}"
    #   print_debug_end(response.code)
    #
    #   return JSON.parse(response.body)['display_name']
    # end

    # def self.register_random_location(group_id, user_id)
    #   print_debug_start("to register a vote with a random address")
    #
    #   uri = build_uri('/api/locationgroup/' + group_id)
    #   http = build_http_object(uri)
    #   request = Net::HTTP::Post.new(uri)
    #   request.basic_auth(api_key, api_secret)
    #   request.set_form_data('usr_id': user_id, 'address': get_random_address)
    #
    #   response = http.request(request)
    #
    #   print_debug_end(response.code)
    # end

    private

      def self.print_debug_start(description = "")
        puts "\n\n\n" + "-"*60
        puts "Sending request to EMAPIC API " + description
      end

      def self.print_debug_end(http_code)
        puts "Response code: #{http_code}"
        puts "-"*60 + "\n\n\n"
      end

      def self.api_host
        ENV['EMAPIC_HOST'].split(':')[0]
      end

      def self.api_port
        port = ENV['EMAPIC_HOST'].split(':')[1]
        (port.nil? 80 : port)
      end

      def self.emapic_login
        ENV['EMAPIC_LOGIN']
      end

      def self.api_key
        ENV['EMAPIC_KEY']
      end

      def self.api_secret
        ENV['EMAPIC_SECRET']
      end
  end
end
